==> haskell-edit-distance-vector-1.0.0.4-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edit-distance-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: edit-distance-vector
version: 1.0.0.4
id: edit-distance-vector-1.0.0.4-JJ22e9m60cFLGIHSxnibJc
key: edit-distance-vector-1.0.0.4-JJ22e9m60cFLGIHSxnibJc
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/edit-distance-vector
synopsis: Calculate edit distances and edit scripts between vectors.
description:
    An implementation of the Wagner–Fischer dynamic programming algorithm to
    find the optimal edit script and cost between two sequences.
    .
    The implementation in this package is specialised to sequences represented
    with "Data.Vector" but is otherwise agnostic to:
    .
    * The type of values in the vectors;
    .
    * The type representing edit operations; and
    .
    * The type representing the cost of operations.
    .
category: Data, Data Structures, Algorithms
abi: 72c086987c07acf13d5956d3086f46bc
exposed: True
exposed-modules:
    Data.Vector.Distance
import-dirs: /usr/lib/ghc-8.6.5/site-local/edit-distance-vector-1.0.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/edit-distance-vector-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/edit-distance-vector-1.0.0.4
hs-libraries: HSedit-distance-vector-1.0.0.4-JJ22e9m60cFLGIHSxnibJc
depends:
    base-4.12.0.0 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-edit-distance-vector/html/edit-distance-vector.haddock
haddock-html: /usr/share/doc/haskell-edit-distance-vector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edit-distance-vector-1.0.0.4-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-edit-distance-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: edit-distance-vector
version: 1.0.0.4
id: edit-distance-vector-1.0.0.4-AJbRhp4pAb32LJmZr1urGv
key: edit-distance-vector-1.0.0.4-AJbRhp4pAb32LJmZr1urGv
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/edit-distance-vector
synopsis: Calculate edit distances and edit scripts between vectors.
description:
    An implementation of the Wagner–Fischer dynamic programming algorithm to
    find the optimal edit script and cost between two sequences.
    .
    The implementation in this package is specialised to sequences represented
    with "Data.Vector" but is otherwise agnostic to:
    .
    * The type of values in the vectors;
    .
    * The type representing edit operations; and
    .
    * The type representing the cost of operations.
    .
category: Data, Data Structures, Algorithms
abi: 01935c2f450c21d2c664e035aaac61ee
exposed: True
exposed-modules:
    Data.Vector.Distance
import-dirs: /usr/lib/ghc-8.6.5/site-local/edit-distance-vector-1.0.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/edit-distance-vector-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/edit-distance-vector-1.0.0.4
hs-libraries: HSedit-distance-vector-1.0.0.4-AJbRhp4pAb32LJmZr1urGv
depends:
    base-4.12.0.0 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-edit-distance-vector/html/edit-distance-vector.haddock
haddock-html: /usr/share/doc/haskell-edit-distance-vector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
